You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@openoffice.apache.org by ms...@apache.org on 2020/10/06 22:21:30 UTC

[openoffice] branch AOO42X updated: Fixed typos (beeing -> being) and some more

This is an automated email from the ASF dual-hosted git repository.

mseidel pushed a commit to branch AOO42X
in repository https://gitbox.apache.org/repos/asf/openoffice.git


The following commit(s) were added to refs/heads/AOO42X by this push:
     new d92770c  Fixed typos (beeing -> being) and some more
d92770c is described below

commit d92770c00e4403324508aa84976f7c1906440926
Author: mseidel <ms...@apache.org>
AuthorDate: Wed Oct 7 00:18:14 2020 +0200

    Fixed typos (beeing -> being) and some more
    
    (cherry picked from commit 2df387e6904e94f6cff3cb41c0152fdd0b8cf63c)
---
 main/connectivity/source/commontools/conncleanup.cxx           | 2 +-
 main/cui/source/options/optgdlg.cxx                            | 8 ++++----
 main/cui/source/options/optlingu.cxx                           | 2 +-
 main/forms/source/component/DatabaseForm.cxx                   | 2 +-
 main/forms/source/component/DatabaseForm.hxx                   | 2 +-
 main/odk/examples/DevelopersGuide/Forms/SalesFilter.java       | 2 +-
 main/offapi/com/sun/star/awt/XKeyHandler.idl                   | 2 +-
 main/offapi/com/sun/star/form/XRestoreListener.idl             | 2 +-
 main/offapi/com/sun/star/form/XSubmitListener.idl              | 2 +-
 main/offapi/com/sun/star/frame/Controller.idl                  | 2 +-
 main/offapi/com/sun/star/sdb/ContentLoader.idl                 | 4 ++--
 main/offapi/com/sun/star/sdb/ErrorMessageDialog.idl            | 2 +-
 main/offapi/com/sun/star/ui/XContextMenuInterception.idl       | 2 +-
 main/offapi/com/sun/star/ui/XContextMenuInterceptor.idl        | 2 +-
 main/sfx2/source/config/evntconf.cxx                           | 2 +-
 main/sfx2/source/toolbox/tbxitem.cxx                           | 4 ++--
 main/svtools/inc/svtools/editbrowsebox.hxx                     | 4 ++--
 main/svtools/source/brwbox/editbrowsebox.cxx                   | 2 +-
 main/svtools/source/control/toolbarmenu.cxx                    | 2 +-
 main/svtools/source/control/toolbarmenuimp.hxx                 | 2 +-
 main/svtools/source/control/valueimp.hxx                       | 4 ++--
 main/svtools/source/svrtf/parrtf.cxx                           | 2 +-
 main/svx/source/fmcomp/gridctrl.cxx                            | 2 +-
 main/svx/source/form/fmshimp.cxx                               | 2 +-
 main/toolkit/inc/toolkit/controls/accessiblecontrolcontext.hxx | 2 +-
 main/vcl/unx/generic/app/saldisp.cxx                           | 2 +-
 main/vos/inc/vos/execabl.hxx                                   | 2 +-
 main/xmloff/inc/xmloff/formlayerimport.hxx                     | 4 ++--
 main/xmloff/source/forms/elementimport.hxx                     | 4 ++--
 main/xmloff/source/forms/layerexport.hxx                       | 2 +-
 main/xmloff/source/text/txtflde.cxx                            | 2 +-
 31 files changed, 40 insertions(+), 40 deletions(-)

diff --git a/main/connectivity/source/commontools/conncleanup.cxx b/main/connectivity/source/commontools/conncleanup.cxx
index 811c5a0..c932088 100644
--- a/main/connectivity/source/commontools/conncleanup.cxx
+++ b/main/connectivity/source/commontools/conncleanup.cxx
@@ -195,7 +195,7 @@ namespace dbtools
 	//---------------------------------------------------------------------
 	void SAL_CALL OAutoConnectionDisposer::disposing( const EventObject& _rSource ) throw (RuntimeException)
 	{
-		// the rowset is beeing disposed, and nobody has set a new ActiveConnection in the meantime
+		// the rowset is being disposed, and nobody has set a new ActiveConnection in the meantime
 		if ( isRowSetListening() )
 			stopRowSetListening();
 
diff --git a/main/cui/source/options/optgdlg.cxx b/main/cui/source/options/optgdlg.cxx
index 7ad1d1f..4775269 100644
--- a/main/cui/source/options/optgdlg.cxx
+++ b/main/cui/source/options/optgdlg.cxx
@@ -730,14 +730,14 @@ OfaViewTabPage::OfaViewTabPage(Window* pParent, const SfxItemSet& rSet ) :
 	aAAPointLimitUnits.SetPosSizePixel( aPos, aSize );
 #else
 	// on this platform, we do not have the anti aliasing options - move the other checkboxes accordingly
-	// (in the resource, the coordinates are calculated for the AA options beeing present)
+	// (in the resource, the coordinates are calculated for the AA options being present)
 	Control* pMiscOptions[] =
 	{
         &aMenuFL, &aMenuIconsFT, &aMenuIconsLB,
         &aFontListsFL, &aFontShowCB, &aFontHistoryCB
 	};
 
-	// temporaryly create the checkbox for the anti aliasing (we need to to determine it's pos)
+	// temporarily create the checkbox for the anti aliasing (we need to determine its pos)
 	CheckBox* pFontAntiAliasing	= new CheckBox( this, CUI_RES( CB_FONTANTIALIASING ) );
     sal_Int32 nMoveUp = aMenuFL.GetPosPixel().Y() - pFontAntiAliasing->GetPosPixel().Y();
 	DELETEZ( pFontAntiAliasing );
@@ -1280,7 +1280,7 @@ OfaLanguagesTabPage::OfaLanguagesTabPage( Window* pParent, const SfxItemSet& rSe
     }
     catch (Exception &e)
     {
-        // we'll just leave the box in it's default setting and won't
+        // we'll just leave the box in its default setting and won't
         // even give it event handler...
         OString aMsg = OUStringToOString(e.Message, RTL_TEXTENCODING_ASCII_US);
         OSL_ENSURE(sal_False, aMsg.getStr());
@@ -1463,7 +1463,7 @@ sal_Bool OfaLanguagesTabPage::FillItemSet( SfxItemSet& rSet )
     }
     catch (Exception& e)
     {
-        // we'll just leave the box in it's default setting and won't
+        // we'll just leave the box in its default setting and won't
         // even give it event handler...
         OString aMsg = OUStringToOString(e.Message, RTL_TEXTENCODING_ASCII_US);
         OSL_ENSURE(sal_False, aMsg.getStr());
diff --git a/main/cui/source/options/optlingu.cxx b/main/cui/source/options/optlingu.cxx
index bb0795a..a5b386d 100644
--- a/main/cui/source/options/optlingu.cxx
+++ b/main/cui/source/options/optlingu.cxx
@@ -1193,7 +1193,7 @@ SvxLinguTabPage::SvxLinguTabPage( Window* pParent,
         // was started with.
         // Also we have to take care to not loose the last reference when
         // someone else removes a dictionary from the list.
-        // removed dics will be replaced by NULL new entries be added to the end
+        // Removed dics will be replaced by NULL new entries be added to the end.
         // Thus we may use indizes as consistent references.
         aDics = xDicList->getDictionaries();
 
diff --git a/main/forms/source/component/DatabaseForm.cxx b/main/forms/source/component/DatabaseForm.cxx
index ee4bf3e..39795db 100644
--- a/main/forms/source/component/DatabaseForm.cxx
+++ b/main/forms/source/component/DatabaseForm.cxx
@@ -2806,7 +2806,7 @@ void ODatabaseForm::stopSharingConnection( )
 			xSharedConnComp->removeEventListener( static_cast< XLoadListener* >( this ) );
 
 		// no need to dispose the conn: we're not the owner, this is our parent
-		// (in addition, this method may be called if the connection is beeing disposed while we use it)
+		// (in addition, this method may be called if the connection is being disposed while we use it)
 
 		// reset the property
 		xSharedConn.clear();
diff --git a/main/forms/source/component/DatabaseForm.hxx b/main/forms/source/component/DatabaseForm.hxx
index db1cd95..f02820c 100644
--- a/main/forms/source/component/DatabaseForm.hxx
+++ b/main/forms/source/component/DatabaseForm.hxx
@@ -490,7 +490,7 @@ private:
 	/// stops sharing the connection with the parent
 	void		stopSharingConnection( );
 
-	/// called when the connection which we share with our parent is beeing disposed
+	/// called when the connection which we share with our parent is being disposed
 	void		disposingSharedConnection( const ::com::sun::star::uno::Reference< ::com::sun::star::sdbc::XConnection >& _rxConn );
 
 	/// checks if we currently share our connection with our parent
diff --git a/main/odk/examples/DevelopersGuide/Forms/SalesFilter.java b/main/odk/examples/DevelopersGuide/Forms/SalesFilter.java
index 4a1fe4d..621b029 100644
--- a/main/odk/examples/DevelopersGuide/Forms/SalesFilter.java
+++ b/main/odk/examples/DevelopersGuide/Forms/SalesFilter.java
@@ -94,7 +94,7 @@ class SalesFilter implements XActionListener, XPropertyChangeListener, XResetLis
 			m_xFilterList.addPropertyChangeListener( "SelectedItems", this );
 			m_xManualFilter.addPropertyChangeListener( "Date", this );
 
-			// want to know about the date field beeing reset
+			// want to know about the date field being reset
 			XReset xReset = UNO.queryReset( m_xManualFilter );
 			xReset.addResetListener( this );
 
diff --git a/main/offapi/com/sun/star/awt/XKeyHandler.idl b/main/offapi/com/sun/star/awt/XKeyHandler.idl
index a283a01..a549634 100644
--- a/main/offapi/com/sun/star/awt/XKeyHandler.idl
+++ b/main/offapi/com/sun/star/awt/XKeyHandler.idl
@@ -57,7 +57,7 @@ published interface XKeyHandler : ::com::sun::star::lang::XEventListener
         when known, with that of other handlers.</p>
 
         <p>Consuming this event does not prevent the pending key-release
-        event from beeing broadcasted.</p>
+        event from being broadcasted.</p>
 
         @param aEvent
             The key event informs about the pressed key.
diff --git a/main/offapi/com/sun/star/form/XRestoreListener.idl b/main/offapi/com/sun/star/form/XRestoreListener.idl
index 1b6c871..8ccbc2b 100644
--- a/main/offapi/com/sun/star/form/XRestoreListener.idl
+++ b/main/offapi/com/sun/star/form/XRestoreListener.idl
@@ -38,7 +38,7 @@
  
 //============================================================================= 
  
-/** receives notifications about data beeing restored.
+/** receives notifications about data being restored.
 	
 	<p>Such a notification is typically sent when the user cancels updating the
 	current record of a database form
diff --git a/main/offapi/com/sun/star/form/XSubmitListener.idl b/main/offapi/com/sun/star/form/XSubmitListener.idl
index a537bc1..4f18097 100644
--- a/main/offapi/com/sun/star/form/XSubmitListener.idl
+++ b/main/offapi/com/sun/star/form/XSubmitListener.idl
@@ -38,7 +38,7 @@
  
 //============================================================================= 
  
-/** receives notifications about data beeing submitted.
+/** receives notifications about data being submitted.
 	
 	<p>The submission may be cancelled, so the listener has the possibility
 	of verifying the data before submission.</p>
diff --git a/main/offapi/com/sun/star/frame/Controller.idl b/main/offapi/com/sun/star/frame/Controller.idl
index b62162d..9083133 100644
--- a/main/offapi/com/sun/star/frame/Controller.idl
+++ b/main/offapi/com/sun/star/frame/Controller.idl
@@ -94,7 +94,7 @@ published service Controller
 
     //-------------------------------------------------------------------------
     /** this interface enables the controller to get interceptors registered that
-        change context menue or prevent them from beeing executed
+        change context menue or prevent them from being executed
 
         <p>
         Don't mix it with <type>XDispatchProviderInterception</type> which
diff --git a/main/offapi/com/sun/star/sdb/ContentLoader.idl b/main/offapi/com/sun/star/sdb/ContentLoader.idl
index 6136a87..018ee75 100644
--- a/main/offapi/com/sun/star/sdb/ContentLoader.idl
+++ b/main/offapi/com/sun/star/sdb/ContentLoader.idl
@@ -85,8 +85,8 @@ published service ContentLoader
 
 		The parameters passed to the 
 		<member scope="com::sun::star::frame">XFrameLoader::load()</member>
-		are forwarded to the object beeing created, 
-		in particular to it's 
+		are forwarded to the object being created, 
+		in particular to its 
 		<type scope="com::sun::star::lang">XInitialization</type>
 		interface.
 	**/
diff --git a/main/offapi/com/sun/star/sdb/ErrorMessageDialog.idl b/main/offapi/com/sun/star/sdb/ErrorMessageDialog.idl
index fbe534f..8d689fb 100644
--- a/main/offapi/com/sun/star/sdb/ErrorMessageDialog.idl
+++ b/main/offapi/com/sun/star/sdb/ErrorMessageDialog.idl
@@ -148,7 +148,7 @@ published service ErrorMessageDialog
 			</li>
 			<li><b>SQLException</b><br/>
 				<type scope="com::sun::star::sdbc">SQLException</type>
-				describing the error which is beeing displayed.<br/>
+				describing the error which is being displayed.<br/>
 				When initializing this value, you may use any derivative of 
 				<type scope="com::sun::star::sdbc">SQLException</type>
 				.
diff --git a/main/offapi/com/sun/star/ui/XContextMenuInterception.idl b/main/offapi/com/sun/star/ui/XContextMenuInterception.idl
index 884cf6a..fcecdbc 100644
--- a/main/offapi/com/sun/star/ui/XContextMenuInterception.idl
+++ b/main/offapi/com/sun/star/ui/XContextMenuInterception.idl
@@ -32,7 +32,7 @@ module com {  module sun {  module star {  module ui {
 
  published interface XContextMenuInterceptor;
 /** This interface enables an object to get interceptors registered that
- change context menue or prevent them from beeing executed.
+ change context menue or prevent them from being executed.
  */
 published interface XContextMenuInterception : ::com::sun::star::uno::XInterface
 {
diff --git a/main/offapi/com/sun/star/ui/XContextMenuInterceptor.idl b/main/offapi/com/sun/star/ui/XContextMenuInterceptor.idl
index 12a5aca..37b78c0 100644
--- a/main/offapi/com/sun/star/ui/XContextMenuInterceptor.idl
+++ b/main/offapi/com/sun/star/ui/XContextMenuInterceptor.idl
@@ -43,7 +43,7 @@ published interface XContextMenuInterceptor : ::com::sun::star::uno::XInterface
 {
     /** notifies the interceptor about the request to execute a ContextMenu.
      The interceptor has to decide whether the menu should be executed with or without
-     beeing modified or may ignore the call.
+     being modified or may ignore the call.
     */
     ContextMenuInterceptorAction notifyContextMenuExecute([in]ContextMenuExecuteEvent aEvent);
 };
diff --git a/main/sfx2/source/config/evntconf.cxx b/main/sfx2/source/config/evntconf.cxx
index d4b87cf..07f0a41 100644
--- a/main/sfx2/source/config/evntconf.cxx
+++ b/main/sfx2/source/config/evntconf.cxx
@@ -153,7 +153,7 @@ uno::Any CreateEventData_Impl( const SvxMacro *pMacro )
 /*
     This function converts a SvxMacro into an Any containing three
     properties. These properties are EventType and Script. Possible
-    values for EventType ar StarBasic, JavaScript, ...
+    values for EventType are StarBasic, JavaScript, ...
     The Script property should contain the URL to the macro and looks
     like "macro://./standard.module1.main()"
 
diff --git a/main/sfx2/source/toolbox/tbxitem.cxx b/main/sfx2/source/toolbox/tbxitem.cxx
index eb87930..12b1427 100644
--- a/main/sfx2/source/toolbox/tbxitem.cxx
+++ b/main/sfx2/source/toolbox/tbxitem.cxx
@@ -128,7 +128,7 @@ static Window* GetTopMostParentSystemWindow( Window* pWindow )
     if ( pWindow )
     {
         // ->manually search topmost system window
-        // required because their might be another system window between this and the top window
+        // required because there might be another system window between this and the top window
         pWindow = pWindow->GetParent();
         SystemWindow* pTopMostSysWin = NULL;
         while ( pWindow )
@@ -874,7 +874,7 @@ void SfxToolBoxControl::createAndPositionSubToolBar( const ::rtl::OUString& rSub
                     static_cast< OWeakObject * >( this ), UNO_QUERY ));
                 xDockWindow->enableDocking( sal_True );
 
-                // keep refererence to UIElement to avoid its destruction
+                // keep reference to UIElement to avoid its destruction
                 if ( pImpl->mxUIElement.is() )
                 {
                     Reference< XComponent > xComponent( pImpl->mxUIElement, UNO_QUERY );
diff --git a/main/svtools/inc/svtools/editbrowsebox.hxx b/main/svtools/inc/svtools/editbrowsebox.hxx
index 363eea7..423f0cd 100644
--- a/main/svtools/inc/svtools/editbrowsebox.hxx
+++ b/main/svtools/inc/svtools/editbrowsebox.hxx
@@ -488,7 +488,7 @@ namespace svt
 			// In ActivateCell, we grab the focus asynchronously, but if between requesting activation
 			// and the asynchornous event the focus has changed, we won't grab it for ourself.
 
-		long	nPaintRow;	// row beeing painted
+		long	nPaintRow;	// row being painted
 		long	nEditRow, nOldEditRow;
 		sal_uInt16	nEditCol, nOldEditCol;
 
@@ -559,7 +559,7 @@ namespace svt
         virtual void    ImplEndTracking();
 
         // when changing a row:
-		// CursorMoving:	cursor is beeing moved, but GetCurRow() still provides the old row
+		// CursorMoving:	cursor is being moved, but GetCurRow() still provides the old row
 		virtual sal_Bool CursorMoving(long nNewRow, sal_uInt16 nNewCol);
 
 		// cursor has been moved
diff --git a/main/svtools/source/brwbox/editbrowsebox.cxx b/main/svtools/source/brwbox/editbrowsebox.cxx
index fa6d4e5..93f8ad8 100644
--- a/main/svtools/source/brwbox/editbrowsebox.cxx
+++ b/main/svtools/source/brwbox/editbrowsebox.cxx
@@ -916,7 +916,7 @@ namespace svt
 		EditBrowseBox * pTHIS = (EditBrowseBox *) this;
 
 		// save the cell content if
-		// a) a selection is beeing made
+		// a) a selection is being made
 		// b) the row is changing
 		if (IsModified() && (nInfo & (ROWCHANGE | COLSELECT | ROWSELECT)) &&
 			!pTHIS->SaveRow())
diff --git a/main/svtools/source/control/toolbarmenu.cxx b/main/svtools/source/control/toolbarmenu.cxx
index a83ada3..ef6bdd3 100644
--- a/main/svtools/source/control/toolbarmenu.cxx
+++ b/main/svtools/source/control/toolbarmenu.cxx
@@ -55,7 +55,7 @@ static Window* GetTopMostParentSystemWindow( Window* pWindow )
     if ( pWindow )
     {
         // ->manually search topmost system window
-        // required because their might be another system window between this and the top window
+        // required because there might be another system window between this and the top window
         pWindow = pWindow->GetParent();
         SystemWindow* pTopMostSysWin = NULL;
         while ( pWindow )
diff --git a/main/svtools/source/control/toolbarmenuimp.hxx b/main/svtools/source/control/toolbarmenuimp.hxx
index 078c4f7..2e7e176 100644
--- a/main/svtools/source/control/toolbarmenuimp.hxx
+++ b/main/svtools/source/control/toolbarmenuimp.hxx
@@ -189,7 +189,7 @@ private:
     virtual void SAL_CALL disposing (void);
 
     /** Check whether or not the object has been disposed (or is in the
-        state of beeing disposed).  If that is the case then
+        state of being disposed).  If that is the case then
         DisposedException is thrown to inform the (indirect) caller of the
         foul deed.
     */
diff --git a/main/svtools/source/control/valueimp.hxx b/main/svtools/source/control/valueimp.hxx
index 13202ba..6cb7f50 100644
--- a/main/svtools/source/control/valueimp.hxx
+++ b/main/svtools/source/control/valueimp.hxx
@@ -233,7 +233,7 @@ private:
     ValueSetItem* getItem (sal_uInt16 nIndex) const;
 
     /** Check whether or not the object has been disposed (or is in the
-        state of beeing disposed).  If that is the case then
+        state of being disposed).  If that is the case then
         DisposedException is thrown to inform the (indirect) caller of the
         foul deed.
     */
@@ -241,7 +241,7 @@ private:
         throw (::com::sun::star::lang::DisposedException);
 
     /** Check whether or not the object has been disposed (or is in the
-        state of beeing disposed).
+        state of being disposed).
 
         @return sal_True, if the object is disposed or in the course
         of being disposed. Otherwise, sal_False is returned.
diff --git a/main/svtools/source/svrtf/parrtf.cxx b/main/svtools/source/svrtf/parrtf.cxx
index 79b2c4c..0656371 100644
--- a/main/svtools/source/svrtf/parrtf.cxx
+++ b/main/svtools/source/svrtf/parrtf.cxx
@@ -179,7 +179,7 @@ int SvRTFParser::_GetNextToken()
 										nUCharOverread = nUCharOverread;
 #endif
 							}
-							aToken.Erase(); // #i47831# erase token to prevent the token from beeing treated as text
+							aToken.Erase(); // #i47831# erase token to prevent the token from being treated as text
 							// read next token
 							nRet = 0;
 							break;
diff --git a/main/svx/source/fmcomp/gridctrl.cxx b/main/svx/source/fmcomp/gridctrl.cxx
index 70ede18..14461d3 100644
--- a/main/svx/source/fmcomp/gridctrl.cxx
+++ b/main/svx/source/fmcomp/gridctrl.cxx
@@ -3840,7 +3840,7 @@ void DbGridControl::FieldListenerDisposing(sal_uInt16 _nId)
 void DbGridControl::disposing(sal_uInt16 _nId, const EventObject& /*_rEvt*/)
 {
 	if (_nId == 0)
-	{	// the seek cursor is beeing disposed
+	{	// the seek cursor is being disposed
 		::osl::MutexGuard aGuard(m_aAdjustSafety);
 		setDataSource(NULL,0); // our clone was disposed so we set our datasource to null to avoid later acces to it
 		if (m_nAsynAdjustEvent)
diff --git a/main/svx/source/form/fmshimp.cxx b/main/svx/source/form/fmshimp.cxx
index d84b2f2..b26e3a0 100644
--- a/main/svx/source/form/fmshimp.cxx
+++ b/main/svx/source/form/fmshimp.cxx
@@ -964,7 +964,7 @@ void FmXFormShell::disposing()
 		aGuard.clear();
 
 		DBG_ASSERT(!m_nInvalidationEvent, "FmXFormShell::~FmXFormShell : still have an invalidation event !");
-			// should habe been deleted while beeing disposed
+			// should have been deleted while being disposed
 
 		m_aMarkTimer.Stop();
 	}
diff --git a/main/toolkit/inc/toolkit/controls/accessiblecontrolcontext.hxx b/main/toolkit/inc/toolkit/controls/accessiblecontrolcontext.hxx
index 993f0bb..b6499a7 100644
--- a/main/toolkit/inc/toolkit/controls/accessiblecontrolcontext.hxx
+++ b/main/toolkit/inc/toolkit/controls/accessiblecontrolcontext.hxx
@@ -49,7 +49,7 @@ namespace toolkit
 		<p><b>life time control<b/><br/>
 		This control should be held weak by the creator (an UNO control), it itself holds a hard reference to the
 		control model, and a weak reference to the control. The reference to the model is freed when the model
-		is beeing disposed.</p>
+		is being disposed.</p>
 	*/
 	class OAccessibleControlContext
 			:public ::comphelper::OAccessibleImplementationAccess
diff --git a/main/vcl/unx/generic/app/saldisp.cxx b/main/vcl/unx/generic/app/saldisp.cxx
index 25acc60..1600615 100644
--- a/main/vcl/unx/generic/app/saldisp.cxx
+++ b/main/vcl/unx/generic/app/saldisp.cxx
@@ -232,7 +232,7 @@ static sal_Bool sal_GetVisualInfo( Display *pDisplay, XID nVID, XVisualInfo &rVI
 // ---------------------------------------------------------------------------
 
 // check whether displaystring is in format N.M or N. or just N
-// with N and M beeing natural numbers
+// with N and M being natural numbers
 static sal_Bool
 sal_IsDisplayNumber( const char *pDisplayString )
 {
diff --git a/main/vos/inc/vos/execabl.hxx b/main/vos/inc/vos/execabl.hxx
index f10e634..7dd1f8d 100644
--- a/main/vos/inc/vos/execabl.hxx
+++ b/main/vos/inc/vos/execabl.hxx
@@ -37,7 +37,7 @@ namespace vos
 	The IExecutable-interface is to be understood as wrapper around
 	your application-code, which allows it to be executed asynchronously.
 
-	Wether you want real asynchronous behaviour or just pseudo-multitasking
+	Whether you want real asynchronous behaviour or just pseudo-multitasking
 	depends on which kind of execution-service you use to execute your executable.
 
 	(E.g. Threadpool/Fiberpool)
diff --git a/main/xmloff/inc/xmloff/formlayerimport.hxx b/main/xmloff/inc/xmloff/formlayerimport.hxx
index d6909b2..9c5fb85 100644
--- a/main/xmloff/inc/xmloff/formlayerimport.hxx
+++ b/main/xmloff/inc/xmloff/formlayerimport.hxx
@@ -91,7 +91,7 @@ namespace xmloff
 
 		/** lookup a control given by id.
 
-			<p>The control must be part of the page which is currently beeing imported, or you must have used
+			<p>The control must be part of the page which is currently being imported, or you must have used
 			seekPage for the page which the control belongs to.</p>
 
 			<p>(And, of course, the control must have been imported already at the moment you call this.)</p>
@@ -123,7 +123,7 @@ namespace xmloff
 			<method>startPage</method> for a new page.</p>
 
 			<p>You should not call seekPage while importing a page (i.e. between startPage and endPage). This will
-			smash this other page beeing imported (seeking back to it will not help you :).</p>
+			smash this other page being imported (seeking back to it will not help you :).</p>
 
 			@see lookupControl
 		*/
diff --git a/main/xmloff/source/forms/layerexport.hxx b/main/xmloff/source/forms/layerexport.hxx
index 4b8801a..385579c 100644
--- a/main/xmloff/source/forms/layerexport.hxx
+++ b/main/xmloff/source/forms/layerexport.hxx
@@ -107,7 +107,7 @@ namespace xmloff
 
         MapPropertySet2Map::iterator
 							m_aCurrentPageIds;
-			// the iterator for the control id map for the page beeing handled
+			// the iterator for the control id map for the page being handled
 		MapPropertySet2Map::iterator
 							m_aCurrentPageReferring;
 			// the same for the map of referring controls
diff --git a/main/xmloff/source/text/txtflde.cxx b/main/xmloff/source/text/txtflde.cxx
index 5b311af..f3db053 100644
--- a/main/xmloff/source/text/txtflde.cxx
+++ b/main/xmloff/source/text/txtflde.cxx
@@ -1207,7 +1207,7 @@ void XMLTextFieldExport::ExportFieldHelper(
 	{
 		// sequence field: name, formula, seq-format
 		OUString sName = GetStringProperty(sPropertyVariableName, rPropSet);
-		// TODO: use reference name only if actually beeing referenced.
+		// TODO: use reference name only if actually being referenced.
 		ProcessString(XML_REF_NAME,
 					  MakeSequenceRefName(
 						  GetInt16Property(sPropertySequenceValue, rPropSet),
diff --git a/main/xmloff/source/forms/elementimport.hxx b/main/xmloff/source/forms/elementimport.hxx
index d43c495..6de140d 100644
--- a/main/xmloff/source/forms/elementimport.hxx
+++ b/main/xmloff/source/forms/elementimport.hxx
@@ -106,7 +106,7 @@ namespace xmloff
 			@param _rImport
 				the importer
 			@param _rEventManager
-				the event attacher manager for the control beeing imported
+				the event attacher manager for the control being imported
 			@param _nPrefix
 				the namespace prefix
 			@param _rName
@@ -324,7 +324,7 @@ namespace xmloff
 	class OReferredControlImport : public OControlImport
 	{
 	protected:
-		::rtl::OUString	m_sReferringControls;	// the list of ids of controls referring to the one beeing imported
+		::rtl::OUString	m_sReferringControls;	// the list of ids of controls referring to the one being imported
 
 	public:
 		OReferredControlImport(